==> gmysql-0.3.0.tar.gz: gmysql-0.3.0/src/createtabledlg.h <==
/*  gmysql -- a graphical frontend to MySQL databases
    Copyright (C) 1998 Stephen R. Dodd <dirk@loth.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __CREATETABLEDLG_H__
#define __CREATETABLEDLG_H__

#include <gtk/gtk.h>
#include "tablelist.h"

#define CREATE_TABLE_DLG(p) ((CreateTableDlg *)p);

typedef struct _CreateTableDlg CreateTableDlg;

struct _CreateTableDlg {
	GtkWidget *dialog;

	GtkWidget *host;
	GtkWidget *db;
	GtkWidget *table;
	GtkWidget *field_list;
	GtkWidget *index_list;

	gint new_table;
	GHashTable *mods;
	GHashTable *idx_mods;
	TableList *owner;
};

CreateTableDlg	*create_table_dlg_new( TableList *owner );
CreateTableDlg	*create_table_dlg_new_modified( TableList *owner, gchar *host,
					gchar *db, gchar *table );
void			create_table_dlg_show( CreateTableDlg *create_table_dlg );
void			create_table_dlg_change_field( CreateTableDlg *create_table_dlg, 
					gchar *old_name, gchar *name, gchar *type, gint user );
void			create_table_dlg_add_field( CreateTableDlg *create_table_dlg, 
					gchar *name, gchar *type, gint user );
void			create_table_dlg_add_index( CreateTableDlg *create_table_dlg, 
					gchar *name, GSList *fields, gint unique, gint user );

#endif /* __CREATETABLEDLG_H__ */

==> gmysql-0.3.1.tar.gz: gmysql-0.3.1/src/createtabledlg.h <==
/*  gmysql -- a graphical frontend to MySQL databases
    Copyright (C) 1998 Stephen R. Dodd <dirk@loth.demon.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __CREATETABLEDLG_H__
#define __CREATETABLEDLG_H__

#include <gtk/gtk.h>
#include "tablelist.h"

#define CREATE_TABLE_DLG(p) ((CreateTableDlg *)p);

typedef struct _CreateTableDlg CreateTableDlg;

struct _CreateTableDlg {
	GtkWidget *dialog;

	GtkWidget *host;
	GtkWidget *db;
	GtkWidget *table;
	GtkWidget *field_list;
	GtkWidget *index_list;

	gint new_table;
	GHashTable *mods;
	GHashTable *idx_mods;
	TableList *owner;
};

CreateTableDlg	*create_table_dlg_new( TableList *owner, gchar *host, gchar* db );
CreateTableDlg	*create_table_dlg_new_modified( TableList *owner, gchar *host,
					gchar *db, gchar *table );
void			create_table_dlg_show( CreateTableDlg *create_table_dlg );
void			create_table_dlg_change_field( CreateTableDlg *create_table_dlg, 
					gchar *old_name, gchar *name, gchar *type, gint user );
void			create_table_dlg_add_field( CreateTableDlg *create_table_dlg, 
					gchar *name, gchar *type, gint user );
void			create_table_dlg_add_index( CreateTableDlg *create_table_dlg, 
					gchar *name, GSList *fields, gint unique, gint user );

#endif /* __CREATETABLEDLG_H__ */
